# -*- coding: utf-8 -*-

"""Top-level package for LexicalRichness."""

__title__ = 'lexicalrichness'
__author__ = """Lucas Shen YS"""
__email__ = 'lucas@lucasshen.com'
__version__ = '0.3.1'

from .lexicalrichness import *
